#!/bin/sh

make || exit 1

die () {
  echo "*** run.sh: $*" 1>&2
  exit 1
}

[ $# =  1 ] || die "argument missing"
[ -f $1 ] || die "argument '$1' not a file"

msg () {
  echo "[run.sh] $*"
}

run () {
  msg "$*"
  $* || exit 1
}

benchmark=$1
base=`basename $1 .aig`
verifyscript="$base/$base.singular"
verifylog="$base/${base}verify.log"
verifyerr="$base/${base}verify.err"


msg "benchmark        $benchmark"
msg "base             $base"
msg "verifyscript     $verifyscript"
msg "verifylog        $certifyingverifylog"
msg "verifyerr        $certifyingverifyerr"

if [ -d $base ]
then
  msg "directory '$base' already exists"
else
  mkdir $base || die "can not generate director '$base'"
  msg "generated directory '$base'"
fi

msg "cleaning up '$base'"

rm -f $verifyscript
rm -f $verifylog $verifyerr

msg "verification: '$verifylog' and '$verifyerr'"
runlim --space-limit=14000 --real-time-limit=1200 \
  ./run-aigmultopoly-then-singular.sh --singular $benchmark $verifyscript --full-adder-rewriting\
  1>$verifylog 2>$verifyerr
msg "verification done."

killall -9 WolframKernel
killall -9 Singular
